==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/macie2/kotlin/inputs/ClassificationJobS3JobDefinitionBucketCriteriaExcludesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.macie2.kotlin.inputs

import com.pulumi.aws.macie2.inputs.ClassificationJobS3JobDefinitionBucketCriteriaExcludesArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 *
 * @property ands An array of conditions, one for each condition that determines which objects to include or exclude from the job. (documented below)
 */
public data class ClassificationJobS3JobDefinitionBucketCriteriaExcludesArgs(
    public val ands: Output<List<ClassificationJobS3JobDefinitionBucketCriteriaExcludesAndArgs>>? =
        null,
) :
    ConvertibleToJava<com.pulumi.aws.macie2.inputs.ClassificationJobS3JobDefinitionBucketCriteriaExcludesArgs> {
    override fun toJava():
        com.pulumi.aws.macie2.inputs.ClassificationJobS3JobDefinitionBucketCriteriaExcludesArgs =
        com.pulumi.aws.macie2.inputs.ClassificationJobS3JobDefinitionBucketCriteriaExcludesArgs.builder()
            .ands(
                ands?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [ClassificationJobS3JobDefinitionBucketCriteriaExcludesArgs].
 */
@PulumiTagMarker
public class ClassificationJobS3JobDefinitionBucketCriteriaExcludesArgsBuilder internal
constructor() {
    private var ands: Output<List<ClassificationJobS3JobDefinitionBucketCriteriaExcludesAndArgs>>? =
        null

    /**
     * @param value An array of conditions, one for each condition that determines which objects to include or exclude from the job. (documented below)
     */
    @JvmName("qupdmsxgjlqoival")
    public suspend
    fun ands(`value`: Output<List<ClassificationJobS3JobDefinitionBucketCriteriaExcludesAndArgs>>) {
        this.ands = value
    }

    @JvmName("ojwpyrhfycajgiry")
    public suspend fun ands(
        vararg
        values: Output<ClassificationJobS3JobDefinitionBucketCriteriaExcludesAndArgs>,
    ) {
        this.ands = Output.all(values.asList())
    }

    /**
     * @param values An array of conditions, one for each condition that determines which objects to include or exclude from the job. (documented below)
     */
    @JvmName("xqqijgysukiiusyt")
    public suspend
    fun ands(values: List<Output<ClassificationJobS3JobDefinitionBucketCriteriaExcludesAndArgs>>) {
        this.ands = Output.all(values)
    }

    /**
     * @param value An array of conditions, one for each condition that determines which objects to include or exclude from the job. (documented below)
     */
    @JvmName("qmcgpjsstwcunodn")
    public suspend
    fun ands(`value`: List<ClassificationJobS3JobDefinitionBucketCriteriaExcludesAndArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.ands = mapped
    }

    /**
     * @param argument An array of conditions, one for each condition that determines which objects to include or exclude from the job. (documented below)
     */
    @JvmName("yjhsnhrbowtklfck")
    public suspend
    fun ands(argument: List<suspend ClassificationJobS3JobDefinitionBucketCriteriaExcludesAndArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            ClassificationJobS3JobDefinitionBucketCriteriaExcludesAndArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.ands = mapped
    }

    /**
     * @param argument An array of conditions, one for each condition that determines which objects to include or exclude from the job. (documented below)
     */
    @JvmName("jrigtpkeaioeqpvl")
    public suspend fun ands(
        vararg
        argument: suspend ClassificationJobS3JobDefinitionBucketCriteriaExcludesAndArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            ClassificationJobS3JobDefinitionBucketCriteriaExcludesAndArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.ands = mapped
    }

    /**
     * @param argument An array of conditions, one for each condition that determines which objects to include or exclude from the job. (documented below)
     */
    @JvmName("xrdrslcwiiyiffwg")
    public suspend
    fun ands(argument: suspend ClassificationJobS3JobDefinitionBucketCriteriaExcludesAndArgsBuilder.() -> Unit) {
        val toBeMapped =
            listOf(
                ClassificationJobS3JobDefinitionBucketCriteriaExcludesAndArgsBuilder().applySuspend {
                    argument()
                }.build(),
            )
        val mapped = of(toBeMapped)
        this.ands = mapped
    }

    /**
     * @param values An array of conditions, one for each condition that determines which objects to include or exclude from the job. (documented below)
     */
    @JvmName("wnjrjjlkckjuijso")
    public suspend fun ands(
        vararg
        values: ClassificationJobS3JobDefinitionBucketCriteriaExcludesAndArgs,
    ) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.ands = mapped
    }

    internal fun build(): ClassificationJobS3JobDefinitionBucketCriteriaExcludesArgs =
        ClassificationJobS3JobDefinitionBucketCriteriaExcludesArgs(
            ands = ands,
        )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/macie2/kotlin/inputs/ClassificationJobS3JobDefinitionBucketCriteriaExcludesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.macie2.kotlin.inputs

import com.pulumi.aws.macie2.inputs.ClassificationJobS3JobDefinitionBucketCriteriaExcludesArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 *
 * @property ands An array of conditions, one for each condition that determines which objects to include or exclude from the job. (documented below)
 */
public data class ClassificationJobS3JobDefinitionBucketCriteriaExcludesArgs(
    public val ands: Output<List<ClassificationJobS3JobDefinitionBucketCriteriaExcludesAndArgs>>? =
        null,
) :
    ConvertibleToJava<com.pulumi.aws.macie2.inputs.ClassificationJobS3JobDefinitionBucketCriteriaExcludesArgs> {
    override fun toJava(): com.pulumi.aws.macie2.inputs.ClassificationJobS3JobDefinitionBucketCriteriaExcludesArgs =
        com.pulumi.aws.macie2.inputs.ClassificationJobS3JobDefinitionBucketCriteriaExcludesArgs.builder()
            .ands(
                ands?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [ClassificationJobS3JobDefinitionBucketCriteriaExcludesArgs].
 */
@PulumiTagMarker
public class ClassificationJobS3JobDefinitionBucketCriteriaExcludesArgsBuilder internal constructor() {
    private var ands: Output<List<ClassificationJobS3JobDefinitionBucketCriteriaExcludesAndArgs>>? =
        null

    /**
     * @param value An array of conditions, one for each condition that determines which objects to include or exclude from the job. (documented below)
     */
    @JvmName("sjjyxnbjpolouoix")
    public suspend fun ands(`value`: Output<List<ClassificationJobS3JobDefinitionBucketCriteriaExcludesAndArgs>>) {
        this.ands = value
    }

    @JvmName("nbhonrxjuwucqpbe")
    public suspend fun ands(vararg values: Output<ClassificationJobS3JobDefinitionBucketCriteriaExcludesAndArgs>) {
        this.ands = Output.all(values.asList())
    }

    /**
     * @param values An array of conditions, one for each condition that determines which objects to include or exclude from the job. (documented below)
     */
    @JvmName("shfkbfpsqdxafbsx")
    public suspend fun ands(values: List<Output<ClassificationJobS3JobDefinitionBucketCriteriaExcludesAndArgs>>) {
        this.ands = Output.all(values)
    }

    /**
     * @param value An array of conditions, one for each condition that determines which objects to include or exclude from the job. (documented below)
     */
    @JvmName("thbbfedcqrgkomtf")
    public suspend fun ands(`value`: List<ClassificationJobS3JobDefinitionBucketCriteriaExcludesAndArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.ands = mapped
    }

    /**
     * @param argument An array of conditions, one for each condition that determines which objects to include or exclude from the job. (documented below)
     */
    @JvmName("kwqrugciutjavlan")
    public suspend fun ands(argument: List<suspend ClassificationJobS3JobDefinitionBucketCriteriaExcludesAndArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            ClassificationJobS3JobDefinitionBucketCriteriaExcludesAndArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.ands = mapped
    }

    /**
     * @param argument An array of conditions, one for each condition that determines which objects to include or exclude from the job. (documented below)
     */
    @JvmName("efvqqesnggwgqsrf")
    public suspend fun ands(vararg argument: suspend ClassificationJobS3JobDefinitionBucketCriteriaExcludesAndArgsBuilder.() -> Unit) {
        val toBeMapped = argument.toList().map {
            ClassificationJobS3JobDefinitionBucketCriteriaExcludesAndArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.ands = mapped
    }

    /**
     * @param argument An array of conditions, one for each condition that determines which objects to include or exclude from the job. (documented below)
     */
    @JvmName("rikmctspokgqbmvd")
    public suspend fun ands(argument: suspend ClassificationJobS3JobDefinitionBucketCriteriaExcludesAndArgsBuilder.() -> Unit) {
        val toBeMapped =
            listOf(
                ClassificationJobS3JobDefinitionBucketCriteriaExcludesAndArgsBuilder().applySuspend {
                    argument()
                }.build(),
            )
        val mapped = of(toBeMapped)
        this.ands = mapped
    }

    /**
     * @param values An array of conditions, one for each condition that determines which objects to include or exclude from the job. (documented below)
     */
    @JvmName("ejxaetjbbkmfwspq")
    public suspend fun ands(vararg values: ClassificationJobS3JobDefinitionBucketCriteriaExcludesAndArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.ands = mapped
    }

    internal fun build(): ClassificationJobS3JobDefinitionBucketCriteriaExcludesArgs =
        ClassificationJobS3JobDefinitionBucketCriteriaExcludesArgs(
            ands = ands,
        )
}
